@@ -1,5 +1,5 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright © 1993, 94, 96, 97, 98, 99, 00 Free Software Foundation, Inc.
+   Copyright © 1993-2018 Free Software Foundation, Inc.
    Contributed by François Pinard <pinard@iro.umontreal.ca>, 1993.
 
    This library is free software; you can redistribute it and/or
@@ -102,6 +102,6 @@ module_atarist (RECODE_OUTER outer)
 }
 
 void
-delmodule_atarist (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
+delmodule_atarist (_GL_UNUSED RECODE_OUTER outer)
 {
 }
