@@ -1,5 +1,5 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright © 1990, 93, 94, 97, 98, 99, 00 Free Software Foundation, Inc.
+   Copyright © 1990-2018 Free Software Foundation, Inc.
    Contributed by François Pinard <pinard@iro.umontreal.ca>, 1988.
 
    This library is free software; you can redistribute it and/or
@@ -285,7 +285,7 @@ static const char *const translation_table[256] =
 
 static bool
 init_latin1_bangbang (RECODE_STEP step,
-		      RECODE_CONST_REQUEST request _GL_ATTRIBUTE_MAYBE_UNUSED,
+		      RECODE_CONST_REQUEST request _GL_UNUSED,
 		      RECODE_CONST_OPTION_LIST before_options,
 		      RECODE_CONST_OPTION_LIST after_options)
 {
@@ -393,6 +393,6 @@ module_bangbang (RECODE_OUTER outer)
 }
 
 void
-delmodule_bangbang (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
+delmodule_bangbang (_GL_UNUSED RECODE_OUTER outer)
 {
 }
