@@ -1,5 +1,5 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright © 1997, 98, 99, 00 Free Software Foundation, Inc.
+   Copyright © 1997-2018 Free Software Foundation, Inc.
    Contributed by François Pinard <pinard@iro.umontreal.ca>, 1997.
 
    This library is free software; you can redistribute it and/or
@@ -436,6 +436,6 @@ module_dump (RECODE_OUTER outer)
 }
 
 void
-delmodule_dump (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
+delmodule_dump (_GL_UNUSED RECODE_OUTER outer)
 {
 }
