@@ -1,5 +1,5 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright © 1990, 93, 97, 98, 99, 00 Free Software Foundation, Inc.
+   Copyright © 1990-2018 Free Software Foundation, Inc.
    Contributed by François Pinard <pinard@iro.umontreal.ca>, 1988.
 
    This library is free software; you can redistribute it and/or
@@ -139,7 +139,7 @@ static unsigned char const ascii_to_ebcdic_ibm[256] =
 
 static bool
 init_ascii_ebcdic (RECODE_STEP step,
-		   RECODE_CONST_REQUEST request _GL_ATTRIBUTE_MAYBE_UNUSED,
+		   RECODE_CONST_REQUEST request _GL_UNUSED,
 		   RECODE_CONST_OPTION_LIST before_options,
 		   RECODE_CONST_OPTION_LIST after_options)
 {
@@ -174,7 +174,7 @@ init_ebcdic_ascii (RECODE_STEP step,
 
 static bool
 init_ascii_ebcdic_ccc (RECODE_STEP step,
-		       RECODE_CONST_REQUEST request _GL_ATTRIBUTE_MAYBE_UNUSED,
+		       RECODE_CONST_REQUEST request _GL_UNUSED,
 		       RECODE_CONST_OPTION_LIST before_options,
 		       RECODE_CONST_OPTION_LIST after_options)
 {
@@ -210,7 +210,7 @@ init_ebcdic_ccc_ascii (RECODE_STEP step,
 
 static bool
 init_ascii_ebcdic_ibm (RECODE_STEP step,
-		       RECODE_CONST_REQUEST request _GL_ATTRIBUTE_MAYBE_UNUSED,
+		       RECODE_CONST_REQUEST request _GL_UNUSED,
 		       RECODE_CONST_OPTION_LIST before_options,
 		       RECODE_CONST_OPTION_LIST after_options)
 {
@@ -268,6 +268,6 @@ module_ebcdic (RECODE_OUTER outer)
 }
 
 void
-delmodule_ebcdic (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
+delmodule_ebcdic (_GL_UNUSED RECODE_OUTER outer)
 {
 }
