@@ -1,5 +1,5 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright © 2008 Free Software Foundation, Inc.
+   Copyright © 2008-2019 Free Software Foundation, Inc.
    Contributed by François Pinard <pinard@iro.umontreal.ca>, 2008.
 
    This library is free software; you can redistribute it and/or
@@ -113,6 +113,6 @@ module_java (RECODE_OUTER outer)
 }
 
 void
-delmodule_java (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
+delmodule_java (_GL_UNUSED RECODE_OUTER outer)
 {
 }
