@@ -1,5 +1,5 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright  2006 Free Software Foundation, Inc.
+   Copyright © 2006-2018 Free Software Foundation, Inc.
    Contributed by Vincent Danjean <vdanjean@debian.org>, 2006.
    Modified from lat1ltex.c
 
@@ -179,6 +179,6 @@ module_latin1_bibtex (RECODE_OUTER outer)
 }
 
 void
-delmodule_latin1_bibtex (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
+delmodule_latin1_bibtex (_GL_UNUSED RECODE_OUTER outer)
 {
 }
