@@ -1,5 +1,5 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright © 1990,92,93,94,96,97,98,99,00 Free Software Foundation, Inc.
+   Copyright © 1990-2023 Free Software Foundation, Inc.
    François Pinard <pinard@iro.umontreal.ca>, 1990.
 
    This program is free software; you can redistribute it and/or modify it
@@ -16,6 +16,7 @@
    along with this program; if not, see <https://www.gnu.org/licenses/>.
 */
 
+#include "config.h"
 #include "common.h"
 
 /*================================\
@@ -85,7 +86,7 @@ close_mixed (struct mixed *mixed)
       && fclose (mixed->subtask.task->input.file) != 0)
     return false;
   if (mixed->subtask.task->output.file
-      && fclose (mixed->subtask.task->output.file))
+      && fclose (mixed->subtask.task->output.file) != 0)
     return false;
   return true;
 }
