@@ -1,6 +1,5 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright © 1997, 98, 99, 00 Free Software Foundation, Inc.
-   This file is part of the GNU C Library.
+   Copyright © 1997-2018 Free Software Foundation, Inc.
    Contributed by François Pinard <pinard@iro.umontreal.ca>, 1997.
 
    This library is free software; you can redistribute it and/or
@@ -115,6 +114,6 @@ module_permutations (RECODE_OUTER outer)
 }
 
 void
-delmodule_permutations (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
+delmodule_permutations (_GL_UNUSED RECODE_OUTER outer)
 {
 }
