@@ -1,5 +1,5 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright © 1996, 97, 98, 99, 00 Free Software Foundation, Inc.
+   Copyright © 1996-2018 Free Software Foundation, Inc.
    Contributed by François Pinard <pinard@iro.umontreal.ca>, 1996.
 
    This library is free software; you can redistribute it and/or
@@ -362,6 +362,6 @@ module_quoted_printable (RECODE_OUTER outer)
 }
 
 void
-delmodule_quoted_printable (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
+delmodule_quoted_printable (_GL_UNUSED RECODE_OUTER outer)
 {
 }
