@@ -1,5 +1,5 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright © 1990,92,93,94,96,97,98,99,00 Free Software Foundation, Inc.
+   Copyright © 1990-2022 Free Software Foundation, Inc.
    Contributed by François Pinard <pinard@iro.umontreal.ca>, 1990.
 
    This library is free software; you can redistribute it and/or
@@ -35,7 +35,7 @@ extern const char *program_name;
 #include <stdarg.h>
 
 _GL_ATTRIBUTE_FORMAT_PRINTF_SYSTEM (2, 3) void
-recode_error (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED, const char *format, ...)
+recode_error (_GL_UNUSED RECODE_OUTER outer, const char *format, ...)
 {
   va_list args;
 
@@ -47,7 +47,7 @@ recode_error (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED, const char *format,
 }
 
 _GL_ATTRIBUTE_FORMAT_PRINTF_SYSTEM (2, 3) void
-recode_perror (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED, const char *format, ...)
+recode_perror (_GL_UNUSED RECODE_OUTER outer, const char *format, ...)
 {
   int saved_errno = errno;
   va_list args;
@@ -551,7 +551,7 @@ recode_format_table (RECODE_REQUEST request,
 	if (underline)
 	  {
 	    *cursor++ = '_';
-	    underline =false;
+	    underline = false;
 	  }
 	*cursor++ = *cursor2;
       }
