@@ -1,5 +1,5 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright © 1990, 93, 97, 98, 99, 00 Free Software Foundation, Inc.
+   Copyright © 1990-2018 Free Software Foundation, Inc.
    Contributed by François Pinard <pinard@iro.umontreal.ca>, 1988.
 
    This library is free software; you can redistribute it and/or
@@ -86,6 +86,6 @@ module_texinfo (RECODE_OUTER outer)
 }
 
 void
-delmodule_texinfo (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
+delmodule_texinfo (_GL_UNUSED RECODE_OUTER outer)
 {
 }
