@@ -1,5 +1,5 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright © 1999, 2000 Free Software Foundation, Inc.
+   Copyright © 1999-2018 Free Software Foundation, Inc.
    Contributed by François Pinard <pinard@iro.umontreal.ca>, 1993.
 
    This library is free software; you can redistribute it and/or
@@ -415,6 +415,6 @@ module_varia (RECODE_OUTER outer)
 }
 
 void
-delmodule_varia (RECODE_OUTER outer _GL_ATTRIBUTE_MAYBE_UNUSED)
+delmodule_varia (_GL_UNUSED RECODE_OUTER outer)
 {
 }
