@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
 # Automatically derive Recode table files from various sources.
-# Copyright © 1993, 1994, 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
+# Copyright © 1993-2000 Free Software Foundation, Inc.
 # François Pinard <pinard@iro.umontreal.ca>, 1993.
 
 # This program is free software; you can redistribute it and/or modify
@@ -489,15 +489,13 @@ class Iconv(Options):
     def complete(self, french):
         def write_charset(format, charset):
             write(format % charset)
-            write(format % (charset + "-ignore"))
             write(format % (charset + "-translit"))
-            write(format % (charset + "-translit-ignore"))
         if not self.do_sources:
             return
         write = Output(self.SOURCES).write
         count = 1
         for charset, aliases in self.data:
-            versions = 4 # Normal, //IGNORE, //TRANSLIT, //TRANSLIT//IGNORE
+            versions = 2 # Normal, //TRANSLIT
             count = count + (versions + len(aliases)) * versions
         write('\n'
               "/* This is derived from Bruno Haible's `libiconv' package.  */"
